@@ -2,6 +2,7 @@ import requests
 from django.conf import settings
 
 from incv_client.cos import COSClient
+from incv_client.ius import IUSClient
 from incv_client.tof import TofClient
 
 
@@ -36,3 +37,7 @@ class INCVUnionClient:
     @property
     def cos(self):
         return COSClient(self)
+
+    @property
+    def ius(self):
+        return IUSClient(self)
